@@ -5,39 +5,40 @@
 #                    Stéphane MANGIN <stephane.mangin@freesbee.fr>
 # Copyright (c) 2012 OSIELL SARL. (http://osiell.com) All Rights Reserved
 #                    Eric Flaux <contact@osiell.com>
-# 
+#
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
 # consequences resulting from its eventual inadequacies and bugs
 # End users who are looking for a ready-to-use solution with commercial
 # garantees and support are strongly adviced to contract a Free Software
 # Service Company
-# 
+#
 # This program is Free Software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 3
 # of the License, or (at your option) any later version.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-# 
+#
 ################################################################################
 
 """
-csv2oerp Access Programming Interface v0.7.
+
+csv2oerp Access Programming Interface v0.6.
 
 """
-import api07
-import models
-from copy import deepcopy, copy
+import csv2oerp
+from copy import deepcopy
 from inspect import stack, getargvalues
 from constants_and_vars import STATS
+__all__ = ['connect', 'Import_session', 'BaseField', 'Custom', 'Relation', 'Custom']
 
 ACTION_PATTERN = {
     'skip': 'SKIP',
@@ -48,11 +49,12 @@ ACTION_PATTERN = {
     'unique': 'UNIQUE',
     'required': 'REQUIRED',
     'router': 'ROUTER',
-    }
+}
 
 
 SERVER = None
 
+
 def connect(*args, **kwargs):
     """Set globals constants needed to initialize a connection to openerp
 
@@ -72,12 +74,12 @@ def connect(*args, **kwargs):
 
     """
     global SERVER
-    SERVER = models.connector.Openerp(*args, **kwargs)
+    SERVER = csv2oerp.api07.Openerp(*args, **kwargs)
 
 
 class Import_session(object):
     """Main class which provides the functionnal part of the importation process.
-    
+
     .. note:: `sys.argv` integrated provides a command line parser.
 
     Here are the available command line arguments::
@@ -87,7 +89,7 @@ class Import_session(object):
         -l LIMIT, --limit=LIMIT     Limit
         -c, --check-mapping         Check mapping template
         -v, --verbose               Verbose mode
-        -d, --debug      
+        -d, --debug
            debug mode
         -q, --quiet                 Doesn't print anything to stdout
 
@@ -99,7 +101,7 @@ class Import_session(object):
         '_logger', '_opts', '_hdlr', '_lang',
         'id', 'name', 'filename', 'delimiter', 'quotechar', 'encoding', 'offset',
         'limit', 'models', 'kw', 'quiet', 'debug', '_session'
-        ]
+    ]
 
     def __init__(self, **kw):
         self.offset = 'offset' in kw and kw['offset']
@@ -111,7 +113,7 @@ class Import_session(object):
         self._columns_mapping = {}
         self._current_mapping = None
         self._session = None
-        
+
     #===========================================================================
     # Accessors
     #===========================================================================
@@ -163,11 +165,11 @@ class Import_session(object):
 
         """
         return SERVER.pwd
-    
+
     @property
     def lines(self):
         """Getting all lines from CSV parser.
-        
+
         :returns: list
 
         """
@@ -191,26 +193,26 @@ class Import_session(object):
         """ Columns mapping configuration.
 
         See ``Creation of your Columns mapping`` for further details.
-        
+
         """
         self._current_mapping = mapping
 
     def set_lang(self, code='fr_FR'):
         return super(Import_session, self).set_lang(code)
-    
+
     def set_logger(self, syslog=False):
         return super(Import_session, self).set_logger(syslog)
 
     def set_input_file(self, filename, delimiter=',', quotechar='"',
-            encoding='utf8'):
+                       encoding='utf8'):
         """ Set the CSV file to use.
-        
+
         """
-        self._session = models.Session(filename,
-                filename, delimiter, quotechar, encoding,
-                offset=self.offset, limit=self.limit,
-                quiet=self.quiet, debug=self.debug,
-                **self.kw)
+        self._session = csv2oerp.api07.Session(filename,
+                                       filename, delimiter, quotechar, encoding,
+                                       offset=self.offset, limit=self.limit,
+                                       quiet=self.quiet, debug=self.debug,
+                                       **self.kw)
 
     #===========================================================================
     # Tools
@@ -224,7 +226,7 @@ class Import_session(object):
 
         """
         return self._session.get_line_from_index(line_num)
-    
+
     def get_lines_from_value(self, column, value):
         """ Retrieve lines which have value at column
 
@@ -236,13 +238,13 @@ class Import_session(object):
 
         """
         return self._session.get_lines_from_value(column, value)
-    
+
     def get_index_from_value(self, column, value, withcast=True):
         """ Retrieve lines which have ``value`` at ``column``
 
         By default ``value`` will be casted by ``column`` value type
         overwrite it by withcast=False
-        
+
         :param column: The column index
         :type column: int
         :param value: The value to compare from
@@ -251,8 +253,8 @@ class Import_session(object):
 
         """
         return self._session.get_index_from_value(column, value,
-                withcast)
-    
+                                                  withcast)
+
     #===========================================================================
     # Public methods
     #===========================================================================
@@ -275,7 +277,7 @@ class Import_session(object):
 
         """
         global SERVER
-        SERVER = models.connector.Openerp(*args, **kwargs)
+        SERVER = csv2oerp.api07.Openerp(*args, **kwargs)
 
     #===========================================================================
     # MiddleWare api06 to api07
@@ -289,7 +291,7 @@ class Import_session(object):
     def set_preconfigure_script(self, filename):
         """ Declare a parrallel script which will be called before importation.
 
-        It must implement a main method which take in params the instance of 
+        It must implement a main method which take in params the instance of
         Import class, it will be able to use all facilities from Import class.
 
         It must return a list of lines (lines already list too)
@@ -297,7 +299,6 @@ class Import_session(object):
         """
         return self._session.set_preconfigure_script(filename)
 
-
     def check_mapping(self):
         """Check mapping for semantics errors.
         http://www.openerp.com/forum/topic31343.html
@@ -317,23 +318,23 @@ class Import_session(object):
                     model = model.split('::')[1]
                     columns = [columns]
                     self._session._logger.info(
-                            "Checking relationnal model '%s' ..." % model,
-                            extra=STATS[self._session.id])
+                        "Checking relationnal model '%s' ..." % model,
+                        extra=STATS[self._session.id])
                 elif model.startswith('NO_CREATE'):
                     model = model.split('::')[1]
                     self._session._logger.info(
-                            "Checking model (without creation) '%s' ..." % model,
-                            extra=STATS[self._session.id])
+                        "Checking model (without creation) '%s' ..." % model,
+                        extra=STATS[self._session.id])
                 elif model.startswith('NO_UPDATE'):
                     model = model.split('::')[1]
                     self._session._logger.info(
-                            "Checking model (without update) '%s' ..." % model,
-                            extra=STATS[self._session.id])
+                        "Checking model (without update) '%s' ..." % model,
+                        extra=STATS[self._session.id])
                 else:
                     self._session._logger.info(
-                            "Checking model '%s' ..." % model,
-                            extra=STATS[self._session.id])
-                
+                        "Checking model '%s' ..." % model,
+                        extra=STATS[self._session.id])
+
                 # Check if value is a well formed tuple
                 for obj in columns:
                     if not hasattr(obj, 'iteritems'):
@@ -343,12 +344,12 @@ throught pairs of item and objects (non relationnal) must be in a list.\n\n"
 
                     for attr, tuple_val in deepcopy(obj).iteritems():
                         self._session._logger.debug(
-                                "Checking field '%s'" % attr,
-                                extra=STATS[self._session.id])
+                            "Checking field '%s'" % attr,
+                            extra=STATS[self._session.id])
                         for patt in ACTION_PATTERN.values():
                             if attr.count(patt):
                                 attr = attr.split('::')[1]
-                        
+
                         try:
                             if callable(tuple_val):
                                 tuple_val = tuple_val()[0]
@@ -356,23 +357,22 @@ throught pairs of item and objects (non relationnal) must be in a list.\n\n"
                             if column is None and not callable(lambda_func):
                                 res += "\t* You must indicate either a \
 column number or a function or both in a field definition, \n\n"
-                            required = False 
+                            required = False
                             obj[attr] = (
-                                    column,
-                                    lambda_func,
-                                    searchable,
-                                    required)
+                                column,
+                                lambda_func,
+                                searchable,
+                                required)
                         except Exception as err:
                             print err
                             res += "\t* '%s' '%s' definition is not well \
 formed, \n\n" % (model, attr)
 
-
         if res != "":
             raise Exception(title + res)
         else:
             return True
-    
+
     #===========================================================================
     # Creation methods
     #===========================================================================
@@ -380,15 +380,15 @@ formed, \n\n" % (model, attr)
         """Object's automatic and abstracted creation from model
 
         Logged public method
-        
+
         :param model: Name of the OERP class model
         :type model: str
         :param data: Data dictionnary to transmit to OERP create/write method
         :type data: dict
         :param search: List of fields to be used for search
         :type search: list
-        :returns: int 
-        
+        :returns: int
+
         """
         if search is None:
             search = []
@@ -412,17 +412,17 @@ formed, \n\n" % (model, attr)
                 (column, callback, searchable) = value()[0]
             except:
                 (column, callback, searchable, required) = value()[0]
-            
+
             # Add this item to search criteria
             if searchable:
                 search.append(field)
             fields.append(
-                   models.fields.Field(
-                       field,
-                       column,
-                       callback,
-                       required=required)
-                   )
+                csv2oerp.api07.Field(
+                    field,
+                    column,
+                    callback,
+                    required=required)
+            )
         return fields, search
 
     def _models_conversion(self):
@@ -442,14 +442,14 @@ formed, \n\n" % (model, attr)
             # Iterate through multiple model's instances
             for data in datas:
                 fields, search = self._fields_conversion(model, data)
-                
+
                 # Create model and inject into models list
-                model_tmp = models.Model(
-                         model,
-                         fields=fields,
-                         create=create,
-                         update=update,
-                         search=search)
+                model_tmp = csv2oerp.api07.Model(
+                    model,
+                    fields=fields,
+                    create=create,
+                    update=update,
+                    search=search)
                 models_tmp.append(model_tmp)
         return models_tmp
 
@@ -459,10 +459,10 @@ formed, \n\n" % (model, attr)
             self._session.bind(SERVER, models)
             return self._session.start()
         return False
-    
+
 
 class BaseField(object):
-    
+
     def __init__(self, column, callback, search, attributes):
         if not column or isinstance(column, int):
             self.column = column
@@ -475,7 +475,8 @@ class BaseField(object):
             else:
                 raise Exception('Column\'s `column` argument must be a list of int or int')
         else:
-            raise Exception('Column\'s `column` argument must be a list of int or int')
+            raise Exception(
+                'Column\'s `column` argument must be a list of int or int')
         if callback and not callable(callback):
             raise Exception('Column\'s `callback` argument must be callable')
         self.callback = callback
@@ -485,7 +486,7 @@ class BaseField(object):
         if attributes and not isinstance(attributes, list):
             raise Exception('Column\'s `search` argument must be a list')
         self.attributes = attributes
-    
+
     def __call__(self):
         return ((self.column, self.callback, self.search), self.attributes)
 
@@ -495,15 +496,15 @@ class Column(BaseField):
     model's field will be allocated to the object's creation.
     Also declares metadatas for each model's field defined in mapping, like
     ``required``, ``readonly`` attributes.
-    
+
     .. versionadded: 0.6
 
     Mapping example::
-        
+
         >>> {
         ...     'model': {
         ...         'field': Column(column=0, callback=None, search=True),
-        ...         } 
+        ...         }
         ...     }
 
     :param column: The actual column number (mandatory)
@@ -527,8 +528,8 @@ class Column(BaseField):
 
     """
     def __init__(self, column=None, callback=None, search=False,
-            required=False, skip=False, ignore=False, replace=False,
-            noupdate=False, unique=False):
+                 required=False, skip=False, ignore=False, replace=False,
+                 noupdate=False, unique=False):
         attributes = []
         # Getting the calling frame from stack
         frame = stack()[0][0]
@@ -544,15 +545,16 @@ class Column(BaseField):
             if kwargs[arg] and arg in ACTION_PATTERN:
                 attributes.append(ACTION_PATTERN[arg])
         return super(Column, self).__init__(column, callback, search, attributes)
-        
+
+
 class Relation(BaseField):
     """ Specify a relation field.
     Also declares metadatas like ``required``, ``readonly`` attributes.
-    
+
     .. versionadded: 0.6
 
     Mapping example::
-        
+
         >>> {
         ...     'model': [
         ...         {
@@ -583,7 +585,7 @@ class Relation(BaseField):
 
     """
     def __init__(self, relation, search=False, required=False, skip=False,
-            noupdate=False, unique=False):
+                 noupdate=False, unique=False):
         callback = lambda *a: relation
         attributes = []
         # Getting the calling frame from stack
@@ -604,15 +606,15 @@ class Relation(BaseField):
 
 class Custom(BaseField):
     """ Specify a custom value for current field.
-    
+
     .. versionadded: 0.6
 
     Mapping example::
-        
+
         >>> mapping = {
         ...     'model': {
         ...         'field': Custom('custom', search=True),
-        ...         } 
+        ...         }
         ...     }
 
     :param value: The value to apply.
@@ -638,13 +640,14 @@ class Custom(BaseField):
             if kwargs[arg] and arg in ACTION_PATTERN:
                 attributes.append(ACTION_PATTERN[arg])
         return super(Custom, self).__init__(None, callback, search, attributes)
-        
+
+
 class Router(BaseField):
     """ Specify the column number and special treatments from which the current
     model's field will be allocated to the object's creation.
     Also declares metadatas for each model's field defined in mapping, like
     ``required``, ``readonly`` attributes.
-    
+
     .. versionadded: 0.6
 
     Mapping example::
@@ -655,7 +658,7 @@ class Router(BaseField):
         >>> {
         ...     'model': {
         ...         'field': Router(column=0, callback=_router),
-        ...         } 
+        ...         }
         ...     }
 
     :param column: The actual column number (mandatory)
@@ -680,4 +683,3 @@ class Router(BaseField):
             if kwargs[arg] and arg in ACTION_PATTERN:
                 attributes.append(ACTION_PATTERN[arg])
         return super(Router, self).__init__(column, callback, False, attributes)
-        
