@@ -30,7 +30,8 @@
 ################################################################################
 
 """
-Fields can be used to configure columns/model's fields mapping.
+Fields / columns binding
+^^^^^^^^^^^^^^^^^^^^^^^^
 
 """
 from csv2oerp import exceptions
@@ -44,8 +45,8 @@ class Field(object):
     :type column: int
     :param field: The actual field name to map to
     :type field: str
-    :param callback: The callback function to apply to returned value
-    :type callback: function
+    :param callback: Pre-treatment by a callback function
+    :type callback: :class:`csv2oerp.callbaks.callback_model`
     :param search: Search for same value before object creation
     :type search: bool
     :param default: Default value if no value found or if custom value (column=None)
@@ -62,8 +63,8 @@ class Field(object):
     :type update: bool
     :param unique: Is this field value must be unique inside current model
     :type unique: bool
-    :param relation: Relation to link to (Model object or list of Model Object)
-    :type relation: Model
+    :param relation: Relation to link to (:class:`csv2oerp.Model` or list of :class:`csv2oerp.Model`)
+    :type relation: :class:`csv2oerp.Model`
     :param overwrite: Overwrite the field value in OpenERP (relation)
     :type overwrite: bool
 
@@ -152,10 +153,8 @@ class Field(object):
     def check(self, session, model, context=None):
         """Check field access fr openerp server
 
-        :param session: The import session used for the test
-        :type session: Session
-        :param model: The model used for the test
-        :type model: Model
+        :param session: An instance of :class:`csv2oerp.Session`
+        :param model: An instance of :class:`csv2oerp.Model`
 
         """
         if context is None:
@@ -171,10 +170,8 @@ class Field(object):
     def get_metadata(self, session, model, context=None):
         """Get metadatas from fields_get methods
 
-        :param session: The import session used for the test
-        :type session: Session
-        :param model: The model used for the test
-        :type model: Model
+        :param session: An instance of :class:`csv2oerp.Session`
+        :param model: An instance of :class:`csv2oerp.Model`
         :returns: dict
 
         example::
@@ -224,10 +221,8 @@ class Field(object):
     def _is_readonly(self, session, model, context=None):
         """Check field access
 
-        :param session: The import session used for the test
-        :type session: Session
-        :param model: The model used for the test
-        :type model: Model
+        :param session: An instance of :class:`csv2oerp.Session`
+        :param model: An instance of :class:`csv2oerp.Model`
         :returns: bool
 
         """
@@ -241,10 +236,8 @@ class Field(object):
     def _is_required(self, session, model, context=None):
         """Check field requirability
 
-        :param session: The import session used for the test
-        :type session: Session
-        :param model: The model used for the test
-        :type model: Model
+        :param session: An instance of :class:`csv2oerp.Session`
+        :param model: An instance of :class:`csv2oerp.Model`
         :returns: bool
 
         """
@@ -258,10 +251,8 @@ class Field(object):
     def _is_field(self, session, model, context=None):
         """Check field validity
 
-        :param session: The import session used for the test
-        :type session: Session
-        :param model: The model used for the test
-        :type model: Model
+        :param session: An instance of :class:`csv2oerp.Session`
+        :param model: An instance of :class:`csv2oerp.Model`
         :returns: bool
 
         """
@@ -277,12 +268,9 @@ class Field(object):
 
         We don't intercept any Exceptions, these from callback would be masqued
 
-        :param callback: Function to be used as callback
-        :type callback: Session
-        :param session: The import session used for the test
-        :type session: Session
-        :param model: The model used for the test
-        :type model: Model
+        :param callback: A :class:`csv2oerp.callbacks.callback_model`
+        :param session: An instance of :class:`csv2oerp.Session`
+        :param model: An instance of :class:`csv2oerp.Model`
         :param value: Value to be transmitted to callback
         :type value: object
         :param line: Current full line
@@ -295,8 +283,8 @@ class Field(object):
     def get_data(self, session, model, line):
         """Return the value relative to the line in argument.
 
-        :param server: The server to interact with
-        :type server: Oerp_instance
+        :param session: An instance of :class:`csv2oerp.Session`
+        :param model: An instance of :class:`csv2oerp.Model`
         :param line: The line to search for
         :type line: list
         :raises: SkipLineException, SkipObjectException, RequiredFieldError
